@@ -3,7 +3,7 @@
 """
 Local storage and configuration for the CLI.
 
-The CLI and Hasher-Matcher-Actioner are roughly parallel, but this isn't a 
+The CLI and Hasher-Matcher-Actioner are roughly parallel, but this isn't a
 scalable service running on AWS. Instead, we have all of our state in
 a file (likely ~/.threatexchange)
 """
@@ -42,6 +42,7 @@ class CLiConfig:
 
     fb_threatexchange_api_token: t.Optional[str] = None
     ncmec_credentials: t.Optional[t.Tuple[str, str]] = None
+    tat_credentials: t.Optional[t.Tuple[str, str]] = None
     stop_ncii_keys: t.Optional[StopNCIICredentials] = None
     extensions: t.Set[str] = field(default_factory=set)
     # Every item needs a default for backwards compatibility
@@ -63,9 +64,9 @@ class CliState(collab_config.CollaborationConfigStoreBase):
 
         self._name_to_ctype = {ft.get_name(): ft.get_config_cls() for ft in fetch_types}
 
-        self._cache: t.Optional[
-            t.Dict[str, collab_config.CollaborationConfigBase]
-        ] = None
+        self._cache: t.Optional[t.Dict[str, collab_config.CollaborationConfigBase]] = (
+            None
+        )
 
         self._init_folders_if_needed()
 
@@ -169,9 +170,7 @@ class _SignalExchangeAccessor:
     def get_all(self) -> t.ValuesView[TSignalExchangeAPICls]:
         return self._parent._mapping.exchange.api_by_name.values()
 
-    def get_instance_for_collab(
-        self, collab: TCollabConfig
-    ) -> SignalExchangeAPI[
+    def get_instance_for_collab(self, collab: TCollabConfig) -> SignalExchangeAPI[
         TCollabConfig,
         fetch_state.FetchCheckpointBase,
         fetch_state.FetchedSignalMetadata,
