@@ -9,6 +9,8 @@ import hashlib
 import pathlib
 import re
 import typing as t
+import random
+import string
 
 from threatexchange.content_type.content_base import ContentType
 from threatexchange.content_type.video import VideoContent
@@ -22,6 +24,7 @@ class VideoMD5Signal(
     signal_base.SimpleSignalType,
     signal_base.BytesHasher,
     HasFbThreatExchangeIndicatorType,
+    signal_base.CanGenerateRandomSignal,
 ):
     """
     Simple signal type for Video MD5s.
@@ -68,6 +71,10 @@ class VideoMD5Signal(
         bytes_hash.update(bytes_)
         return bytes_hash.hexdigest()
 
+    @classmethod
+    def get_random_signal(cls) -> str:
+        return f"{random.randrange(16**32):032x}"
+
     @staticmethod
     def get_examples() -> t.List[str]:
         return ["cab08b36195edb1a1231d2d09fa450e0", "d41d8cd98f00b204e9800998ecf8427e"]
