@@ -15,7 +15,7 @@ def dataclass_dump_file(path: pathlib.Path, obj) -> None:
         dataclass_dump(fp, obj)
 
 
-def _as_dict(obj: t.Any) -> t.Dict[str, t.Any]:
+def dataclass_dump_dict(obj: t.Any) -> t.Dict[str, t.Any]:
     json_dict = dataclasses.asdict(obj)
     # Sanity check - we want to make sure it will also come out the other end
     # And this will wrong-type error if it can't
@@ -25,12 +25,12 @@ def _as_dict(obj: t.Any) -> t.Dict[str, t.Any]:
 
 
 def dataclass_dump(fp: t.IO[str], obj) -> None:
-    json_dict = _as_dict(obj)
+    json_dict = dataclass_dump_dict(obj)
     return json.dump(json_dict, fp, indent=2, default=_json_cast_default)
 
 
 def dataclass_dumps(obj) -> str:
-    json_dict = _as_dict(obj)
+    json_dict = dataclass_dump_dict(obj)
     return json.dumps(json_dict, indent=2, default=_json_cast_default)
 
 
